@@ -133,10 +133,13 @@ def login():
     """ Connect to server and obtain an access token if needed."""
     global channel, bx_token, access_token
     if bx_token is not None:
-        user_id = jwt.decode(bx_token, options={"verify_signature":False})['batchx-id']
-        request_data = auth_pb2.RefreshTokenRequest(user_name=user_id, refresh_token=bx_token)
-        response = make_call(auth_pb2_grpc.AuthServiceStub(channel).RefreshToken, request_data, auth_required=False)
-        access_token = response.access_token
+        token = jwt.decode(bx_token, options={"verify_signature":False});
+        if token['batchx-token-type'] == 'refresh':
+            request_data = auth_pb2.RefreshTokenRequest(user_name=token['batchx-id'], refresh_token=bx_token)
+            response = make_call(auth_pb2_grpc.AuthServiceStub(channel).RefreshToken, request_data, auth_required=False)
+            access_token = response.access_token
+        else:
+            access_token = bx_token
     else:
         raise Exception("Batchx token not set. Please run: bx.connect()")
 
@@ -1008,9 +1011,6 @@ class FilesystemService:
     def CopyRequest(self, **kwargs):
         return filesystem_pb2.CopyRequest(**kwargs)
 
-    def CopyResponse(self, **kwargs):
-        return filesystem_pb2.CopyResponse(**kwargs)
-
     def CreateFolderRequest(self, **kwargs):
         return filesystem_pb2.CreateFolderRequest(**kwargs)
 
